Package: tricycle
Type: Package
Title: tricycle: Transferable Representation and Inference of cell
        cycle
Version: 1.21.0
Authors@R: c(
        person("Shijie", "Zheng", role=c("aut", "cre"), email="shijieczheng@gmail.com"))
Description: The package contains functions to infer and visualize cell cycle 
        process using Single Cell RNASeq data. It exploits the idea of transfer
        learning, projecting new data to the previous learned biologically 
        interpretable space. We provide a pre-learned cell cycle space, 
        which could be used to infer cell cycle time of human and mouse single
        cell samples. In addition, we also offer functions to visualize cell
        cycle time on different embeddings and functions to build new reference.
Depends: R (>= 4.0), SingleCellExperiment
Imports: methods, circular, ggplot2, ggnewscale, AnnotationDbi, scater,
        GenomicRanges, IRanges, S4Vectors, scattermore, dplyr,
        RColorBrewer, grDevices, stats, SummarizedExperiment, utils
Suggests: testthat (>= 3.0.0), BiocStyle, knitr, rmarkdown, CircStats,
        cowplot, htmltools, Seurat, org.Hs.eg.db, org.Mm.eg.db
License: GPL-3
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: FALSE
RoxygenNote: 7.1.2
biocViews: SingleCell, Software, Transcriptomics, RNASeq,
        Transcription, BiologicalQuestion, DimensionReduction,
        ImmunoOncology
URL: https://github.com/hansenlab/tricycle
BugReports: https://github.com/hansenlab/tricycle/issues
git_url: https://git.bioconductor.org/packages/tricycle
git_branch: devel
git_last_commit: f021373
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:40:26 UTC; biocbuild
Author: Shijie Zheng [aut, cre]
Maintainer: Shijie Zheng <shijieczheng@gmail.com>
