# Generated by roxygen2: do not edit by hand

export(circle_scale_legend)
export(diagnose_totalumi)
export(estimate_Schwabe_stage)
export(estimate_cycle_position)
export(fit_periodic_loess)
export(plot_ccposition_den)
export(plot_emb_circle_scale)
export(project_cycle_space)
export(run_pca_cc_genes)
import(ggplot2)
importClassesFrom(AnnotationDbi,AnnotationDb)
importClassesFrom(SingleCellExperiment,SingleCellExperiment)
importClassesFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(AnnotationDbi,mapIds)
importFrom(AnnotationDbi,select)
importFrom(RColorBrewer,brewer.pal)
importFrom(SingleCellExperiment,"reducedDim<-")
importFrom(SingleCellExperiment,altExp)
importFrom(SingleCellExperiment,reducedDim)
importFrom(SingleCellExperiment,reducedDimNames)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,colData)
importFrom(circular,circular)
importFrom(circular,coord2rad)
importFrom(circular,density.circular)
importFrom(dplyr,.data)
importFrom(dplyr,`%>%`)
importFrom(dplyr,filter)
importFrom(ggnewscale,new_scale_color)
importFrom(grDevices,colorRampPalette)
importFrom(methods,is)
importFrom(scattermore,geom_scattermore)
importFrom(stats,cor)
importFrom(stats,loess)
importFrom(stats,predict)
importFrom(utils,data)
importMethodsFrom(AnnotationDbi,colnames)
importMethodsFrom(AnnotationDbi,get)
importMethodsFrom(AnnotationDbi,ncol)
importMethodsFrom(AnnotationDbi,nrow)
importMethodsFrom(GenomicRanges,intersect)
importMethodsFrom(GenomicRanges,union)
importMethodsFrom(IRanges,"colnames<-")
importMethodsFrom(IRanges,"rownames<-")
importMethodsFrom(IRanges,as.matrix)
importMethodsFrom(IRanges,diff)
importMethodsFrom(IRanges,lapply)
importMethodsFrom(IRanges,rownames)
importMethodsFrom(IRanges,table)
importMethodsFrom(IRanges,tolower)
importMethodsFrom(IRanges,toupper)
importMethodsFrom(IRanges,unique)
importMethodsFrom(IRanges,which)
importMethodsFrom(S4Vectors,"%in%")
importMethodsFrom(S4Vectors,do.call)
importMethodsFrom(S4Vectors,levels)
importMethodsFrom(S4Vectors,t)
importMethodsFrom(SingleCellExperiment,"reducedDim<-")
importMethodsFrom(SingleCellExperiment,altExp)
importMethodsFrom(SingleCellExperiment,cbind)
importMethodsFrom(SingleCellExperiment,rbind)
importMethodsFrom(SingleCellExperiment,reducedDim)
importMethodsFrom(SingleCellExperiment,reducedDimNames)
importMethodsFrom(SummarizedExperiment,assay)
importMethodsFrom(SummarizedExperiment,assayNames)
importMethodsFrom(SummarizedExperiment,colData)
importMethodsFrom(SummarizedExperiment,order)
importMethodsFrom(SummarizedExperiment,sort)
importMethodsFrom(scater,runPCA)
