<img src="man/figures/logo.png" align="right" alt="logo.png" width="180" />

# tricycle

<!-- badges: start -->
[![R build status](https://github.com/hansenlab/tricycle/workflows/R-CMD-check-bioc/badge.svg)](https://github.com/hansenlab/tricycle/actions)

<!-- badges: end -->

## Bioconductor release status

|      Branch      |    R CMD check   | Last updated |
|:----------------:|:----------------:|:------------:|
| [_devel_](http://bioconductor.org/packages/devel/bioc/html/tricycle.html) | [![Bioconductor-devel Build Status](http://bioconductor.org/shields/build/devel/bioc/tricycle.svg)](http://bioconductor.org/checkResults/devel/bioc-LATEST/tricycle) | ![](http://bioconductor.org/shields/lastcommit/devel/bioc/tricycle.svg) |
| [_release_](http://bioconductor.org/packages/release/bioc/html/tricycle.html) | [![Bioconductor-release Build Status](http://bioconductor.org/shields/build/release/bioc/tricycle.svg)](http://bioconductor.org/checkResults/release/bioc-LATEST/tricycle) | ![](http://bioconductor.org/shields/lastcommit/release/bioc/tricycle.svg) |

## Installation

```r
if (!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager")
BiocManager::install("tricycle", dependencies = TRUE)


