#' Example SingleCellExperiment dataset
#'
#' This a subset of mouse Neurosphere data. 200 cells from sample AX1 and AX2 were randonly
#' sampled from the full data. All genes in the GO cell cycle gene list and \code{\link{RevelioGeneList}}
#'  as well as other random 573 genes were included.
#'
#' @name neurosphere_example
#' @docType data
#'
#' @usage data(neurosphere_example)
#'
#' @format A \linkS4class{SingleCellExperiment} object of 1500 genes and 400 cells.
#'
#' @keywords datasets
#'
#'
#' @examples
#' data(neurosphere_example)
NULL
